@@ -1,5 +1,5 @@
 from rest_framework.serializers import CharField
-from ai_kit_auth.serializers import UserModel, UserSerializer
+from ai_kit_auth.serializers import UserModel, UserSerializer, RegistrationSerializer
 
 
 class CustomUserSerializer(UserSerializer):
@@ -9,3 +9,6 @@ class CustomUserSerializer(UserSerializer):
 
     def get_test_string(self):
         return "test"
+
+class CustomRegistrationSerializer(RegistrationSerializer):
+    last_name  = CharField(required = True, error_messages={"required": "required", "blank": "blank"})
\ No newline at end of file
