@@ -105,12 +105,13 @@ class RegistrationView(generics.GenericAPIView):
 
     permission_classes = (AllowAny,)
 
-    serializer_class = serializers.RegistrationSerializer
+    serializer_class = api_settings.REGISTRATION_SERIALIZER
 
     def post(self, request, *args, **kwargs):
         user_pre_registered.send(sender=RegistrationView, user_data=request.data)
         serializer = self.serializer_class(data=request.data)
         serializer.is_valid(raise_exception=True)
+        serializer.save()
         return Response({}, status=status.HTTP_201_CREATED)
 
 
@@ -169,9 +170,7 @@ class InitiatePasswordResetView(views.APIView):
     def post(self, request, *args, **kwargs):
         # Find user by identity field
         user = None
-        ident = request.data[
-            "email"
-        ]  # TODO this should be renamed "ident" in the next major release
+        ident = request.data["ident"]
         for field_name in api_settings.USER_IDENTITY_FIELDS:
             field = UserModel._meta.get_field(field_name)
             filter_key = field.name
